@@ -44,7 +44,7 @@ hexbin <-
     c1 <- 2 * floor((xbins *shape)/sqrt(3) + 1.5001)
     imax <- trunc((jmax*c1 -1)/jmax + 1)
     lmax <- jmax * imax
-    ans <- .Fortran("hbin",
+    ans <- .Fortran(`hbin`,
 	      x = as.double(x),
 	      y = as.double(y),
 	      cell = integer(lmax),
@@ -162,7 +162,7 @@ erode.hexbin <- function(hbin, cdfcut = 0.5)
     n <- length(cell)
     bdim <- hbin@dimen
     L <- bdim[1] * bdim[2]
-    ans <- .Fortran("herode",
+    ans <- .Fortran(`herode`,
 		    cell  = as.integer(cell),
 		    cnt	  = as.integer(cnt),
 		    n	  = n,
@@ -238,7 +238,8 @@ gplot.hexbin <-
 
     ## ----- plotting starts ------------------------
     if (newpage) grid.newpage()
-    hv.ob <- hexViewport(x, offset = unit(legend,"inches"))
+    hv.ob <- hexViewport(x, xbnds=x@xbnds, ybnds=x@ybnds,
+                         offset = unit(legend,"inches"))
     pushViewport(hv.ob@hexVp.off)
     grid.rect()
     if(xaxt != "n") grid.xaxis()
@@ -255,7 +256,7 @@ gplot.hexbin <-
 		gp = gpar(fontsize = 18))
     if(type != "n") {
         if(clip == "on") {
-            popViewport()
+            upViewport()
             pushViewport(hv.ob@hexVp.on)
         }
         grid.hexagons(x, style = style, minarea = minarea, maxarea = maxarea,
@@ -265,7 +266,7 @@ gplot.hexbin <-
 		      colramp = colramp, verbose = verbose)
     }
 
-    popViewport()# plot
+    upViewport()# plot
     #popViewport()# fig
     ## ----- Legend ------------------------
     if(legend > 0) {
@@ -308,7 +309,7 @@ gplot.hexbin <-
                            trans = trans, inv = inv, colorcut = colorcut,
 			   density = density, border = border, pen = pen,
 			   colramp = colramp)
-	    popViewport()
+	    upViewport()
 	}
     }
 
